@@ -64,8 +64,8 @@ class ReviewDAO(object):
 class Reviewer(object):
     def __init__(
             self, api_url, page_uuid, page_url, page_score,
-            increase_lambda_tax_method=None, config=None, validators=[], facters=[],
-            async_get=None, wait=None, wait_timeout=None, db=None, cache=None, publish=None,
+            config=None, validators=[], facters=[], async_get=None,
+            wait=None, wait_timeout=None, db=None, cache=None, publish=None,
             fact_definitions=None, violation_definitions=None):
 
         self.db = db
@@ -79,7 +79,6 @@ class Reviewer(object):
         self.page_score = page_score
 
         self.ping_method = None
-        self.increase_lambda_tax_method = increase_lambda_tax_method
 
         self.review_dao = ReviewDAO(self.page_uuid, self.page_url)
 
@@ -181,6 +180,7 @@ class Reviewer(object):
                                                       text)
             logging.error(msg)
             if headers is not None:
+                logging.warning('Response is from cache: %s' % response.from_cache)
                 logging.warning('Headers for "%s": %s' % (url, headers))
             return
 
@@ -242,9 +242,6 @@ class Reviewer(object):
     def get_url(self, url):
         return join(self.api_url.rstrip('/'), url.lstrip('/'))
 
-    def increase_lambda_tax(self, tax):
-        self.increase_lambda_tax_method(tax)
-
     def enqueue(self, urls):
         if not urls:
             return
@@ -284,7 +281,7 @@ class Reviewer(object):
         Review.save_review(
             self.page_uuid, data, self.db,
             self.fact_definitions, self.violation_definitions,
-            self.cache, self.publish
+            self.cache, self.publish, self.config
         )
 
     def wait_for_async_requests(self):
