@@ -13,7 +13,7 @@ from octopus.limiter.redis.per_domain import Limiter
 from holmes import __version__
 from holmes.reviewer import Reviewer, InvalidReviewError
 from holmes.utils import load_classes, count_url_levels
-from holmes.models import Settings, Worker, Page, Domain
+from holmes.models import Worker, Page, Domain
 from holmes.models import Limiter as LimiterModel
 from holmes.cli import BaseCLI
 
@@ -157,8 +157,6 @@ class HolmesWorker(BaseWorker):
     def do_work(self):
         self.debug('Started doing work...')
 
-        self._remove_zombie_workers()
-
         if self._ping_api():
             err = None
             job = self._load_next_job()
